**Example 1: 删除角色权限边界**



Input: 

```
tccli cam DeleteRolePermissionsBoundary --cli-unfold-argument  \
    --RoleId 1234567
```

Output: 
```
{
    "Response": {
        "RequestId": "4097a057-19c9-45bd-ad12-b4225a75c085"
    }
}
```

